==> drupal_helper-8.x-1.20.tar.gz: drupal_helper/src/TwigExtension/DrupalHelperTwigExtension.php <==
<?php

namespace Drupal\drupal_helper\TwigExtension;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\views\Views;


/**
 * Class DrupalHelperTwigExtension.
 */
class DrupalHelperTwigExtension extends \Twig_Extension {

    /**
     * {@inheritdoc}
     */
    public function getTokenParsers() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getNodeVisitors() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getFilters() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getTests() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getFunctions() {
        return [
            'time_ago_fr' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'time_elapsed_string']),
            'current_user' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_current_user']),
            'current_lang' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_current_lang']),
            'is_login' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'isLoginTwig']),
            'current_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_current_url']),
            'get_parameter' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_get_parameter']),
            'node_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'node_url']),
            'block_load_by_type' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'block_load_by_type']),
            'get_module_path' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'get_module_path']),
            'base_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'base_url']),
            'taxonomy_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'taxonomy_url']),
            'node_url_alias' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_node_url_alias']),
            'die' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'die_twig']),
            'array_values' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'array_value_twig']),
            'hasRole' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'has_role_twig']),
            'paragraph_form' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'render_form_paragraph_twig']),
            'id_by_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_id_by_url']),
            'taxonomy_children' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twgi_taxonomy_children']),
            'in_array' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_in_array']),
            'current_url_alias' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_current_url_alias']),
            'config' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_config']),
            'var_dump' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_var_dump']),
            'path_theme' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_get_current_path_theme']),
            'modulo' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'modulo_twig']),
            'render_view' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_render_view']),
            'theme_logo' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_theme_logo']),
            'price' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_price_format']),
            'count_comments' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'count_comments']),
            'views_result' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'views_result']),
            'strtotime' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_strtotime']),
            'array_push' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_array_push']),
            'terms' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'terms']),
            'json_encode' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'json_encode_twig']),
             'unRender' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'unRender']),
             'parameter' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_parameter']), 
             'message' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_message']),
             'array_column' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_array_column']),
             'redirect' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_redirect']),
             'time' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_time']),
             'render_form_entity' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'render_form_entity_twig']),
             'is_url_exist' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'is_url_exist_twig']),
             'json_decode' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'json_decode_twig']),
             'get_block_custom_by_info' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'get_block_custom_by_info_twig']),
             'get_block_custom_id_by_info' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'get_block_custom_id_by_info_twig']),
             'render_block_custom' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'render_block_custom_twig']),
             'render_views' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'render_views_twig']),
             'image' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'image_twig']),
             'helper' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'helper_twig'])
      
            ];
    }
    public static function image_twig($media,$option = []){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->image($media,$option); 
    }
    public static function render_views_twig($view_name,$diplay_id,$argument=[]){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->views->render_views($view_name,$diplay_id,$argument); 
    }
    public static function render_block_custom_twig($block_id) {
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->views->render_block_custom($block_id); 
    }
    
    public static function get_block_custom_id_by_info_twig($info){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        $array =  $twig_base->helper->get_block_custom_by_info($info);
        if(!empty($array)){
              return end(array_keys($array));
        }
        return [];
    }

    public static function get_block_custom_by_info_twig($info){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->get_block_custom_by_info($info);
    }
    public static function json_decode_twig($json){
        return json_decode($json, true);
    } 
    public static function is_url_exist_twig($url){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->isExistUrl($url);
    }
    public static function twig_redirect($url){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->redirectTo($url);
    }
    public static function twig_array_column($array, $string){
        return array_column($array, $string);
    }
    public static function twig_message($message , $status = null){
        $message = t($message) ;
        \Drupal::messenger()->addMessage($message,$status);
    }
    public static function twig_parameter($parameter_name = null){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->get_parameter($parameter_name);
  
    }
    public static function unRender($item){
        return $item->__toString();
    }
    public static function json_encode_twig($array){
        $InText = json_encode($array);
        return str_replace('"',"'",$InText);
    }
    public static function time_elapsed_string($time_ago)
    {


        $cur_time   = time();
        $time_elapsed   = $cur_time - $time_ago;
        $seconds    = $time_elapsed ;
        $minutes    = round($time_elapsed / 60 );
        $hours      = round($time_elapsed / 3600);
        $days       = round($time_elapsed / 86400 );
        $weeks      = round($time_elapsed / 604800);
        $months     = round($time_elapsed / 2600640 );
        $years      = round($time_elapsed / 31207680 );
        // Seconds
        if($seconds <= 60){
            return "juste maintenant";
        }
        //Minutes
        else if($minutes <=60){
            if($minutes==1){
                return "il y a une minute";
            }
            else{
                return "il y a $minutes minutes";
            }
        }
        //Hours
        else if($hours <=24){
            if($hours==1){
                return "il y a une heure";
            }else{
                return "il y a $hours heures ";
            }
        }
        //Days
        else if($days <= 7){
            if($days==1){
                return "hier";
            }else{
                return "il y a $days jours";
            }
        }
        //Weeks
        else if($weeks <= 4.3){
            if($weeks==1){
                return "il y a une semaine";
            }else{
                return "il y a $weeks semaines ";
            }
        }
        //Months
        else if($months <=12){
            if($months==1){
                return "il y a un mois";
            }else{
                return "il y a $months mois";
            }
        }
        //Years
        else{
            if($years==1){
                return "il y a un an";
            }else{
                return "il y a $years années";
            }
        }


    }

    public static function terms($vid){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->taxonomy_load_multi_by_vid($vid);
    }
    public static function twig_array_push($array,$item,$key = null){
        if($key){
          $array[$key] = $item ;
        }else{
            $array[] = $item ;
        }
        return $array;
    }
    public static function twig_time(){
        return time();
    }
    public static function twig_strtotime($date){
        $date = new DrupalDateTime($date);
        return $date->getTimestamp();
    }
    public static function views_result($view_name,$diplay_id){
        $view = Views::getView($view_name);
        $view->setDisplay($diplay_id);
        $view->execute();
        return $view->result ;
    }
    public static function count_comments($nid){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->count_comments($nid);
    }
    public static function helper_twig(){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base;
    }
    public static function twig_price_format($price,$decimal_number=0 ,$decimal_point=',' , $thousands_sep=' ') {
        return number_format($price,$decimal_number, $decimal_point, $thousands_sep);
    }
    public static function twig_theme_logo(){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->theme_logo();
    }
    public static function twig_render_view($view_mode ,$item, $entity_type='node'){
        $view_builder = \Drupal::entityTypeManager()->getViewBuilder($entity_type);
        $result =  $view_builder->view($item, $view_mode);
        return \Drupal::service('renderer')->renderRoot($result);
    }
    public static function modulo_twig($a , $b){
        return  ($a % $b);
    }
    public static function twig_config($config_base,$config_name){
        $config = \Drupal::config($config_base);
        return  $config->get($config_name);

    }

    public static function twig_get_current_path_theme(){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        global  $base_url ;
        return $base_url.'/'.$twig_base->helper->get_current_path_theme();
    }
    public static function twig_current_url_alias(){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->current_url_alias();
    }
    public static function twig_node_url_alias($nid){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->node_url_alias($nid);
    }

    public static function twig_var_dump($content){
        return var_dump($content);
    }
    public static function twig_in_array($item , $array){
        return in_array($item,$array);
    }
    public static function twgi_taxonomy_children($vid , $tid){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->taxonomy_children($vid , $tid);
    }
    public static function twig_id_by_url($url = null){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->get_numeric_args_url($url);
    }
    public static function render_form_paragraph_twig($bundle,$id=null){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->form->render_form_paragraph($bundle,$id);
    }
    public static function render_form_entity_twig($entity,$bundle,$id = null){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->form->render_form_entity($entity,$bundle,$id);
    }


    public static function has_role_twig($role_name,$uid){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->user->hasRole($role_name,$uid);
    }
    public static function array_value_twig($array){
        if($array==null){
            $array =[];
        }
        return  array_values($array);
    }
    public static function twig_current_lang(){
        return  $language = \Drupal::languageManager()->getCurrentLanguage()->getId();
    }
    public static function twig_current_user(){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return  $twig_base->helper->current_user();
    }
    public  static function die_twig(){
        return die();
    }
    public static function isLoginTwig() {
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return  $twig_base->helper->is_login();
    }
    public static function twig_current_url(){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return  $twig_base->helper->current_url();
    }
    public static function twig_get_parameter(){
        return   \Drupal::request()->query->all();
    }


    public static function node_url($nid){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->node_url($nid);
    }
    public static function block_load_by_type($type){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->block_custom_load_by_type($type);

    }

    public static function  get_module_path($module_name){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->get_module_path($module_name);
    }

    public  static function base_url(){
        global $base_url ;
        return $base_url;
    }

    public  static function taxonomy_url($tid){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        $alias = $twig_base->helper->taxonomy_url_alias($tid);

        return $alias  ;
    }

    /**
     * {@inheritdoc}
     */
    public function getOperators() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getName() {
        return 'drupal_helper.twig.extension';
    }

}

==> drupal_helper-8.x-2.0.tar.gz: drupal_helper/src/TwigExtension/DrupalHelperTwigExtension.php <==
<?php

namespace Drupal\drupal_helper\TwigExtension;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\views\Views;


/**
 * Class DrupalHelperTwigExtension.
 */
class DrupalHelperTwigExtension extends \Twig_Extension {

    /**
     * {@inheritdoc}
     */
    public function getTokenParsers() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getNodeVisitors() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getFilters() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getTests() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getFunctions() {
        return [
            'time_ago_fr' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'time_elapsed_string']),
            'current_user' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_current_user']),
            'current_lang' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_current_lang']),
            'is_login' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'isLoginTwig']),
            'current_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_current_url']),
            'get_parameter' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_get_parameter']),
            'node_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'node_url']),
            'block_load_by_type' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'block_load_by_type']),
            'get_module_path' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'get_module_path']),
            'base_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'base_url']),
            'taxonomy_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'taxonomy_url']),
            'node_url_alias' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_node_url_alias']),
            'die' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'die_twig']),
            'array_values' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'array_value_twig']),
            'hasRole' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'has_role_twig']),
            'paragraph_form' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'render_form_paragraph_twig']),
            'id_by_url' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_id_by_url']),
            'taxonomy_children' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twgi_taxonomy_children']),
            'in_array' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_in_array']),
            'current_url_alias' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_current_url_alias']),
            'config' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_config']),
            'var_dump' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_var_dump']),
            'path_theme' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_get_current_path_theme']),
            'modulo' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'modulo_twig']),
            'render_view' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_render_view']),
            'theme_logo' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_theme_logo']),
            'price' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_price_format']),
            'count_comments' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'count_comments']),
            'views_result' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'views_result']),
            'strtotime' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_strtotime']),
            'array_push' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_array_push']),
            'terms' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'terms']),
            'json_encode' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'json_encode_twig']),
             'unRender' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'unRender']),
             'parameter' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_parameter']), 
             'message' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_message']),
             'array_column' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_array_column']),
             'redirect' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_redirect']),
             'time' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'twig_time']),
              'render_form_entity' => new \Twig_Function_Function(['Drupal\drupal_helper\TwigExtension\DrupalHelperTwigExtension', 'render_form_entity_twig'])


            ];
    }
    
    public static function twig_redirect($url){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->redirectTo($url);
    }
    public static function twig_array_column($array, $string){
        return array_column($array, $string);
    }
    public static function twig_message($message , $status = null){
        $message = t($message) ;
        \Drupal::messenger()->addMessage($message,$status);
    }
    public static function twig_parameter($parameter_name = null){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->get_parameter($parameter_name);
  
    }
    public static function unRender($item){
        return $item->__toString();
    }
    public static function json_encode_twig($array){
        $InText = json_encode($array);
        return str_replace('"',"'",$InText);
    }
    public static function time_elapsed_string($time_ago)
    {


        $cur_time   = time();
        $time_elapsed   = $cur_time - $time_ago;
        $seconds    = $time_elapsed ;
        $minutes    = round($time_elapsed / 60 );
        $hours      = round($time_elapsed / 3600);
        $days       = round($time_elapsed / 86400 );
        $weeks      = round($time_elapsed / 604800);
        $months     = round($time_elapsed / 2600640 );
        $years      = round($time_elapsed / 31207680 );
        // Seconds
        if($seconds <= 60){
            return "juste maintenant";
        }
        //Minutes
        else if($minutes <=60){
            if($minutes==1){
                return "il y a une minute";
            }
            else{
                return "il y a $minutes minutes";
            }
        }
        //Hours
        else if($hours <=24){
            if($hours==1){
                return "il y a une heure";
            }else{
                return "il y a $hours heures ";
            }
        }
        //Days
        else if($days <= 7){
            if($days==1){
                return "hier";
            }else{
                return "il y a $days jours";
            }
        }
        //Weeks
        else if($weeks <= 4.3){
            if($weeks==1){
                return "il y a une semaine";
            }else{
                return "il y a $weeks semaines ";
            }
        }
        //Months
        else if($months <=12){
            if($months==1){
                return "il y a un mois";
            }else{
                return "il y a $months mois";
            }
        }
        //Years
        else{
            if($years==1){
                return "il y a un an";
            }else{
                return "il y a $years années";
            }
        }


    }

    public static function terms($vid){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->taxonomy_load_multi_by_vid($vid);
    }
    public static function twig_array_push($array,$item,$key = null){
        if($key){
          $array[$key] = $item ;
        }else{
            $array[] = $item ;
        }
        return $array;
    }
    public static function twig_time(){
        return time();
    }
    public static function twig_strtotime($date){
        $date = new DrupalDateTime($date);
        return $date->getTimestamp();
    }
    public static function views_result($view_name,$diplay_id){
        $view = Views::getView($view_name);
        $view->setDisplay($diplay_id);
        $view->execute();
        return $view->result ;
    }
    public static function count_comments($nid){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->count_comments($nid);
    }
    public static function twig_price_format($price,$decimal_number=0 ,$decimal_point=',' , $thousands_sep=' ') {
        return number_format($price,$decimal_number, $decimal_point, $thousands_sep);
    }
    public static function twig_theme_logo(){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->theme_logo();
    }
    public static function twig_render_view($view_mode ,$item, $entity_type='node'){
        $view_builder = \Drupal::entityTypeManager()->getViewBuilder($entity_type);
        $result =  $view_builder->view($item, $view_mode);
        return \Drupal::service('renderer')->renderRoot($result);
    }
    public static function modulo_twig($a , $b){
        return  ($a % $b);
    }
    public static function twig_config($config_base,$config_name){
        $config = \Drupal::config($config_base);
        return  $config->get($config_name);

    }

    public static function twig_get_current_path_theme(){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        global  $base_url ;
        return $base_url.'/'.$twig_base->helper->get_current_path_theme();
    }
    public static function twig_current_url_alias(){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->current_url_alias();
    }
    public static function twig_node_url_alias($nid){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->node_url_alias($nid);
    }

    public static function twig_var_dump($content){
        return var_dump($content);
    }
    public static function twig_in_array($item , $array){
        return in_array($item,$array);
    }
    public static function twgi_taxonomy_children($vid , $tid){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->taxonomy_children($vid , $tid);
    }
    public static function twig_id_by_url($url = null){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->get_numeric_args_url($url);
    }
    public static function render_form_paragraph_twig($bundle,$id=null){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->form->render_form_paragraph($bundle,$id);
    }
    public static function render_form_entity_twig($entity,$bundle,$id = null){
        $twig_base = new \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->form->render_form_entity($entity,$bundle,$id);
    }


    public static function has_role_twig($role_name,$uid){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->user->hasRole($role_name,$uid);
    }
    public static function array_value_twig($array){
        if($array==null){
            $array =[];
        }
        return  array_values($array);
    }
    public static function twig_current_lang(){
        return  $language = \Drupal::languageManager()->getCurrentLanguage()->getId();
    }
    public static function twig_current_user(){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return  $twig_base->helper->current_user();
    }
    public  static function die_twig(){
        return die();
    }
    public static function isLoginTwig() {
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return  $twig_base->helper->is_login();
    }
    public static function twig_current_url(){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return  $twig_base->helper->current_url();
    }
    public static function twig_get_parameter(){
        return   \Drupal::request()->query->all();
    }


    public static function node_url($nid){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->node_url($nid);
    }
    public static function block_load_by_type($type){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->block_custom_load_by_type($type);

    }

    public static function  get_module_path($module_name){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        return $twig_base->helper->get_module_path($module_name);
    }

    public  static function base_url(){
        global $base_url ;
        return $base_url;
    }

    public  static function taxonomy_url($tid){
        $twig_base = new  \Drupal\drupal_helper\DrupalHelper();
        $alias = $twig_base->helper->taxonomy_url_alias($tid);

        return $alias  ;
    }

    /**
     * {@inheritdoc}
     */
    public function getOperators() {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function getName() {
        return 'drupal_helper.twig.extension';
    }

}
